@@ -47,22 +47,6 @@ void KitaThreadInfo::setReadNum( const QString& url, int num )
     instance->m_readDict.insert( url, num );
 }
 
-int KitaThreadInfo::resNum( const QString& url )
-{
-    KitaThreadInfo * instance = KitaThreadInfo::getInstance();
-    if ( instance->m_resNumDict.contains( url ) ) {
-        return instance->m_resNumDict[ url ];
-    } else {
-        return 0;
-    }
-}
-
-void KitaThreadInfo::setResNum( const QString& url, int num )
-{
-    KitaThreadInfo * instance = KitaThreadInfo::getInstance();
-    instance->m_resNumDict.insert( url, num );
-}
-
 void KitaThreadInfo::replace( const QString fromURL, const QString toURL )
 {
     QMap<QString, int>::Iterator it;
@@ -79,18 +63,6 @@ void KitaThreadInfo::replace( const QString fromURL, const QString toURL )
             it = instance->m_readDict.begin(); // TODO äᤤˡ?
         }
     }
-
-    QMap<QString, int>::Iterator it2;
-    for ( it2 = instance->m_resNumDict.begin(); it2 != instance->m_resNumDict.end(); ++it2 ) {
-        QString url = it2.key();
-        int num = it2.data();
-        if ( url.find( fromURL ) == 0 ) {
-            url = url.replace( 0, fromURL.length(), toURL );
-            instance->m_resNumDict.erase( it2 );
-            instance->m_resNumDict.insert( url, num );
-            it2 = instance->m_resNumDict.begin();
-        }
-    }
 }
 
 void KitaThreadInfo::removeThreadInfo( const QString& url )
