@@ -111,7 +111,7 @@ KitaMainWindow::KitaMainWindow()
 
     // read dock status
     m_bbsDock->loadSession();
-    m_subjectDock->loadSession();
+    m_boardDock->loadSession();
     m_threadDock->loadSession();
     m_naviDock->loadSession();
     m_imgDock->loadSession();
@@ -121,7 +121,7 @@ KitaMainWindow::KitaMainWindow()
     readDockConfig( &dockConfig );
 
     // show subject dock
-    m_subjectDock->slotShowDock();
+    m_boardDock->slotShowDock();
 
     // show thread view
     m_threadDock->slotShowDock();
@@ -156,11 +156,11 @@ KitaMainWindow::KitaMainWindow()
              SLOT( slotOpenURLRequest( const KURL&, const KParts::URLArgs& ) ) );
 
     connect( signalCollection, SIGNAL( openURLRequestExt(
-                                           const KURL&, const KParts::URLArgs&, QString, int, int,
-                                           const KURL&, const KURL&, const QString&, const QString& ) ),
+                                           const KURL&, const KParts::URLArgs&, QString, int,
+                                           const KURL& ) ),
              SLOT( slotOpenURLRequestExt(
-                       const KURL& , const KParts::URLArgs&, QString, int, int,
-                       const KURL&, const KURL&, const QString&, const QString& ) ) );
+                       const KURL& , const KParts::URLArgs&, QString, int,
+                       const KURL& ) ) );
 
     connect( signalCollection, SIGNAL( setMainCaption( const QString& ) ),
              SLOT( slotSetMainCaption( const QString& ) ) );
@@ -216,7 +216,7 @@ KitaMainWindow::~KitaMainWindow()
 {
     /* save dock status */
     m_bbsDock->saveSession();
-    m_subjectDock->saveSession();
+    m_boardDock->saveSession();
     m_threadDock->saveSession();
     m_naviDock->saveSession();
     m_imgDock->saveSession();
@@ -302,7 +302,7 @@ void KitaMainWindow::setupActions()
 
     m_subjectListAction = new KToggleAction( i18n( "Show subject list" ),
                           0,
-                          m_subjectDock,
+                          m_boardDock,
                           SLOT( slotToggleShowHide() ),
                           actionCollection(),
                           "window_show_subject_list" );
@@ -401,7 +401,7 @@ void KitaMainWindow::setupActions()
     setXMLFile( "kitaui.rc" );
     KMainWindow::createGUI();
     factory() ->addClient( m_bbsTab );
-    factory() ->addClient( m_subjectTab );
+    factory() ->addClient( m_boardTab );
     factory() ->addClient( m_threadTab );
     factory() ->addClient( m_imgTab );
     factory() ->addClient( m_naviTab );
@@ -517,25 +517,25 @@ void KitaMainWindow::resetWindowsDef3() { resetWindows( 3 ); }
 void KitaMainWindow::resetWindows( int pattern )
 {
     if ( !m_dummyDock || !m_threadDock || !m_bbsDock
-            || !m_subjectDock || !m_naviDock || !m_imgDock || !m_writeDock ) return ;
+            || !m_boardDock || !m_naviDock || !m_imgDock || !m_writeDock ) return ;
 
     makeDockVisible( m_threadDock );
     makeDockVisible( m_bbsDock );
-    makeDockVisible( m_subjectDock );
+    makeDockVisible( m_boardDock );
     makeDockVisible( m_naviDock );
     makeDockVisible( m_imgDock );
     makeDockVisible( m_writeDock );
 
     makeDockInvisible( m_threadDock );
     makeDockInvisible( m_bbsDock );
-    makeDockInvisible( m_subjectDock );
+    makeDockInvisible( m_boardDock );
     makeDockInvisible( m_naviDock );
     makeDockInvisible( m_imgDock );
     makeDockInvisible( m_writeDock );
 
     m_threadDock->manualDock( m_dummyDock, KDockWidget::DockTop, 100 );
     m_bbsDock->manualDock( m_threadDock, KDockWidget::DockLeft, 20 );
-    m_subjectDock->manualDock( m_threadDock, KDockWidget::DockTop, 25 );
+    m_boardDock->manualDock( m_threadDock, KDockWidget::DockTop, 25 );
     m_imgDock->manualDock( m_threadDock, KDockWidget::DockTop, 25 );
     m_writeDock->manualDock( m_threadDock, KDockWidget::DockBottom, 75 );
     m_naviDock->manualDock( m_threadDock, KDockWidget::DockBottom, 50 );
@@ -548,7 +548,7 @@ void KitaMainWindow::resetWindows( int pattern )
         /* setSession( docked, tabbed ) */
         m_threadDock ->setSession( TRUE, FALSE );
         m_bbsDock ->setSession( TRUE, FALSE );
-        m_subjectDock->setSession( TRUE, FALSE );
+        m_boardDock->setSession( TRUE, FALSE );
         m_imgDock ->setSession( TRUE, FALSE );
         m_writeDock ->setSession( TRUE, FALSE );
         m_naviDock ->setSession( TRUE, FALSE );
@@ -575,7 +575,7 @@ void KitaMainWindow::resetWindows( int pattern )
         /* setSession( docked, tabbed ) */
         m_threadDock ->setSession( TRUE, FALSE );
         m_bbsDock ->setSession( TRUE, FALSE );
-        m_subjectDock->setSession( TRUE, FALSE );
+        m_boardDock->setSession( TRUE, FALSE );
         m_imgDock ->setSession( FALSE, FALSE );
         m_writeDock ->setSession( FALSE, FALSE );
         m_naviDock ->setSession( FALSE, FALSE );
@@ -591,7 +591,7 @@ void KitaMainWindow::resetWindows( int pattern )
         /*----------------------------------------*/
     case 2:
 
-        m_subjectDock->manualDock( m_threadDock, KDockWidget::DockCenter, 0 );
+        m_boardDock->manualDock( m_threadDock, KDockWidget::DockCenter, 0 );
 
         m_imgDock->toDesktop();
         m_writeDock->toDesktop();
@@ -604,7 +604,7 @@ void KitaMainWindow::resetWindows( int pattern )
         /* setSession( docked, tabbed ) */
         m_threadDock ->setSession( TRUE, TRUE );
         m_bbsDock ->setSession( TRUE, FALSE );
-        m_subjectDock->setSession( TRUE, TRUE );
+        m_boardDock->setSession( TRUE, TRUE );
         m_imgDock ->setSession( FALSE, FALSE );
         m_writeDock ->setSession( FALSE, FALSE );
         m_naviDock ->setSession( FALSE, FALSE );
@@ -620,7 +620,7 @@ void KitaMainWindow::resetWindows( int pattern )
         /*----------------------------------------*/
     case 3:
 
-        m_subjectDock->manualDock( m_threadDock, KDockWidget::DockCenter, 0 );
+        m_boardDock->manualDock( m_threadDock, KDockWidget::DockCenter, 0 );
         m_naviDock->manualDock( m_threadDock, KDockWidget::DockCenter, 0 );
         m_imgDock->manualDock( m_threadDock, KDockWidget::DockCenter, 0 );
 
@@ -631,7 +631,7 @@ void KitaMainWindow::resetWindows( int pattern )
         /* setSession( docked, tabbed ) */
         m_threadDock ->setSession( TRUE, TRUE );
         m_bbsDock ->setSession( TRUE, FALSE );
-        m_subjectDock->setSession( TRUE, TRUE );
+        m_boardDock->setSession( TRUE, TRUE );
         m_imgDock ->setSession( TRUE, TRUE );
         m_writeDock ->setSession( TRUE, FALSE );
         m_naviDock ->setSession( TRUE, TRUE );
@@ -651,10 +651,10 @@ void KitaMainWindow::resetWindows( int pattern )
 
 void KitaMainWindow::windowToggleView()
 {
-    //FIXME: m_subjectDock->dockSite() & KDockWidget::DockCenter != 0 ʳΤȤϤɤ롩
+    //FIXME: m_boardDock->dockSite() & KDockWidget::DockCenter != 0 igai no toki ha dousuru?
     kdDebug() << "Do toggle" << endl;
-    if ( !m_subjectDock->isVisible()
-            || !m_subjectDock->isActiveWindow() ) m_subjectDock->slotShowDock();
+    if ( !m_boardDock->isVisible()
+            || !m_boardDock->isActiveWindow() ) m_boardDock->slotShowDock();
     else {
         m_threadDock->slotShowDock();
     }
@@ -697,9 +697,9 @@ void KitaMainWindow::setupView()
     setMainDockWidget( m_dummyDock );
 
     /* Subject View */
-    m_subjectDock = new KitaSubjectDock( manager(), "subject", 0L, 0L, i18n( "subject" ), i18n( "subject" ) );
-    m_subjectTab = m_subjectDock->setup();
-    connect( m_subjectDock, SIGNAL( checkToggleAction( bool ) ), SLOT( slotCheckSubjectToggleAction( bool ) ) );
+    m_boardDock = new KitaBoardDock( manager(), "subject", 0L, 0L, i18n( "subject" ), i18n( "subject" ) );
+    m_boardTab = m_boardDock->setup();
+    connect( m_boardDock, SIGNAL( checkToggleAction( bool ) ), SLOT( slotCheckSubjectToggleAction( bool ) ) );
 
     /* Board View */
     m_bbsDock = new KitaBBSDock( manager(), "board", 0L, 0L, i18n( "board" ), i18n( "board" ) );
@@ -788,12 +788,11 @@ void KitaMainWindow::slotOpenURLRequest( const KURL& url, const KParts::URLArgs&
 void KitaMainWindow::slotOpenURLRequestExt(
     const KURL& url, const KParts::URLArgs& args,
     QString mimetype,
-    int usr1, int usr2,
-    const KURL& usrUrl1, const KURL& usrUrl2,
-    const QString& usrStr1, const QString& usrStr2 )
+    int usr1,
+    const KURL& usrUrl1 )
 {
     // FIXME: support be.2ch.net
-    if ( url.host() == "be.2ch.net" ) {
+    if ( url.host() == "be.2ch.net" && url.path().contains( "/test/p.php", true ) < 1 ) {
         QMessageBox::warning( this,
                               "Kita",
                               i18n( "be.2ch.net is currently not supported." ) );
@@ -811,15 +810,16 @@ void KitaMainWindow::slotOpenURLRequestExt(
     /* if usr1 == 1, open the board with new tab. */
     if ( mimetype == "kita_open_2chboard" ) {
         bool withNewTab = ( usr1 == 1 );
-        m_subjectDock->slotLoadBoard( url, withNewTab );
+        m_boardDock->slotLoadBoard( url, withNewTab );
         return ;
     }
 
     /* open 2ch thread */
     /* if usr1 == 1, open the thread with new tab. */
     if ( mimetype == "kita_open_2chthread" ) {
-        bool withNewTab = ( usr1 == 1 );
-        m_threadDock->slotShowThread( url, withNewTab );
+        bool withNewTab = ( usr1 == 1 || usr1 == 2 );
+        bool byBackground = ( usr1 == 2 );
+        m_threadDock->slotShowThread( url, withNewTab, byBackground );
         return ;
     }
 
@@ -925,7 +925,7 @@ void KitaMainWindow::saveCache()
 
 void KitaMainWindow::setFont( const QFont& font )
 {
-    m_subjectTab->setFont( font );
+    m_boardTab->setFont( font );
     m_bbsTab->setFont( font );
 }
 
