@@ -164,7 +164,7 @@ void KitaHTMLPart::connectSignals()
     connect( this, SIGNAL( redrawHTMLPart( const KURL&, bool ) ), signalCollection, SIGNAL( redrawHTMLPart( const KURL&, bool ) ) );
     connect( signalCollection, SIGNAL( redrawHTMLPart( const KURL&, bool ) ), SLOT( slotRedrawHTMLPart( const KURL& , bool ) ) );
     connect( signalCollection, SIGNAL( redrawAllHTMLPart( bool ) ), SLOT( slotRedrawAllHTMLPart( bool ) ) );
-    connect( signalCollection, SIGNAL( setFontOfHTMLPart() ), SLOT( slotSetFontOfHTMLPart() ) );
+    connect( signalCollection, SIGNAL( threadFaceChanged() ), SLOT( slotSetFaceOfHTMLPart() ) );
     connect( signalCollection, SIGNAL( setStyleSheetOfHTMLPart() ), SLOT( slotSetStyleSheetOfHTMLPart() ) );
 
     /* popup */
@@ -419,7 +419,7 @@ void KitaHTMLPart::slotRedrawAllHTMLPart( bool force )
 }
 
 /* public slot */
-void KitaHTMLPart::slotSetFontOfHTMLPart()
+void KitaHTMLPart::slotSetFaceOfHTMLPart()
 {
     QFont font = KitaConfig::threadFont();
 
