@@ -509,7 +509,7 @@ QString KitaWriteView::setPostStr()
     ( ret += "&mail=" ) += KURL::encode_string( mailLine->text(), mib );
     ( ret += "&MESSAGE=" ) += KURL::encode_string( bodyText->text(), mib );
     ( ret += "&bbs=" ) += Kita::BoardManager::boardID( m_datURL );
-    ( ret += "&hana=mogera" );
+    ( ret += "&suka=pontan" );
 
     /* key */
     if ( m_mode == WRITEMODE_NORMAL ) ( ret += "&key=" ) += Kita::DatManager::threadID( m_datURL );
